@@ -4,7 +4,7 @@
 pub mod configuration;
 
 /// Database functionality
-pub mod databases;
+pub mod datastores;
 /// generates name based on patterns
 pub mod name_generator;
 
@@ -15,4 +15,7 @@ pub mod number_generator;
 pub mod string_generator;
 
 /// generates random dates from 1970 to now
-pub mod date_generator;
\ No newline at end of file
+pub mod date_generator;
+
+/// generates bytes
+pub mod byte_generator;
\ No newline at end of file
